@@ -3,7 +3,7 @@
 #' This function transforms its argument to HTML and then copy it to the
 #' clipboard or to a file for later use in an external application.
 #' 
-#' @aliases copie copie.default copy.default
+#' @aliases copie copie.default clipcopy.default
 #' @param obj object to be copied
 #' @param ... arguments passed to \code{R2HTML::HTML}
 #' @details
@@ -14,29 +14,29 @@
 #' tab <- table(cut(iris$Sepal.Length,8),cut(iris$Sepal.Width,4))
 #' \dontrun{copie(tab)}
 #' ptab <- rprop(tab, percent=TRUE)
-#' \dontrun{copy(ptab)}
+#' \dontrun{clipcopy(ptab)}
 #' @seealso \code{\link[R2HTML]{HTML}}, \code{\link[questionr]{format.proptab}}
 #' @keywords connection 
-#' @export copy copy.default copie copie.default 
+#' @export clipcopy clipcopy.default copie copie.default 
 
-`copy` <-
+`clipcopy` <-
 function (obj, ...) {
-  UseMethod("copy")
+  UseMethod("clipcopy")
 }
-copie <- copy
+copie <- clipcopy
 
 #' @return \code{NULL}
 #'
-#' @rdname copy
-#' @method copy default
-#' @S3method copy default
+#' @rdname clipcopy
+#' @method clipcopy default
+#' @S3method clipcopy default
 #' @aliases copie.proptab
 #' @param append if TRUE, append to the file instead of replacing it
 #' @param file if TRUE, export to a file instead of the clipboard
 #' @param filename name of the file to export to
 #' @param clipboard.size under Windows, size of the clipboard in kB
 
-`copy.default` <-
+`clipcopy.default` <-
 function (obj, append=FALSE, file=FALSE, filename="temp.html", clipboard.size=4096, ...) {
   require(R2HTML)
   if (file) {
@@ -55,28 +55,28 @@ function (obj, append=FALSE, file=FALSE, filename="temp.html", clipboard.size=40
   close(conn)
 }
 
-copie.default <- copy.default
+copie.default <- clipcopy.default
 
 
 #' @return \code{NULL}
 #'
-#' @rdname copy
-#' @method copy proptab
-#' @S3method copy proptab
+#' @rdname clipcopy
+#' @method clipcopy proptab
+#' @S3method clipcopy proptab
 #' @aliases copie.proptab
 #' @param percent whether to add a percent sign in each cell
 #' @param digits number of digits to display
 #' @param justify justification
-#' @seealso \code{\link[questionr]{copy}}, \code{\link[questionr]{format.proptab}}
-#' @export copy.proptab copie.proptab
+#' @seealso \code{\link[questionr]{clipcopy}}, \code{\link[questionr]{format.proptab}}
+#' @export clipcopy.proptab copie.proptab
 
-`copy.proptab` <-
+`clipcopy.proptab` <-
 function (obj, percent=NULL, digits=NULL, justify="right", ...) {
   if (!inherits(obj, "proptab")) stop("Object is not of class proptab")
   obj <- format.proptab(obj, digits=digits, percent=percent, justify=justify)
   copie.default(obj, ...)
 }
-copie.proptab <- copy.proptab
+copie.proptab <- clipcopy.proptab
 
 #' Rename a data frame column
 #'
